{ config, lib, pkgs, ... }:

let
  inherit (lib) mkIf mkMerge mkThenElse;
  annuaire = config.r6d.machines;
  currentMachine = annuaire."${config.networking.fqdn}";
  flags = currentMachine.configurationFlags;
in

mkIf true {

  nixpkgs.config.packageOverrides = pkgs: {
    clawsMail = pkgs.clawsMail.override {
      enablePgp = true;
      enablePluginArchive = true;
      #enablePluginFancy = false; # nécessite wekitgtk qui est troué # Option supprimée dans NixOS 20.03
      enablePluginPdf = true;
      enablePluginRavatar = true;
      enablePluginSmime = true;
      enablePluginVcalendar = true;
      enableSpellcheck = true;
    };

    ffmpeg-full = pkgs.ffmpeg-full.override {
      nonfreeLicensing = true;
      nvenc  = true;
    };

    # bug connu : https://nixos.org/nix-dev/2014-December/015225.html
    # find /nix/store/  -maxdepth 1 -type d -name "*gnuradio-*"
    # Commande pour générer le path : find /nix/store/  -maxdepth 1 -type d -name "*gnuradio-*"|paste -d: -s -
    gnuradio-with-packages = pkgs.gnuradio-with-packages.override {
      extraPackages = with pkgs; [
        gnuradio-ais
        gnuradio-gsm
        gnuradio-nacl
        gnuradio-osmosdr    # support des dongle Realtek
        gnuradio-rds        # support du décodage de RDS sur les radio FM
      ];
    };

    mumble = pkgs.mumble.override { pulseSupport = true; };
  };

  #nixpkgs.config.permittedInsecurePackages = [
  #  "webkitgtk-2.4.11"       # pour que le plugin fancy de claws-mail fonctionne
  #];
}
