{ config, lib, pkgs, ... }:

let
  inherit (lib) mkIf mkMerge mkThenElse;
  annuaire = config.r6d.machines;
  currentMachine = annuaire."${config.networking.fqdn}";
  flags = currentMachine.configurationFlags;
in

mkIf true {

  # Paquets
  environment.systemPackages = with pkgs; [
      byobu         # permet de se déconnecter d'un terminal sans l'arréter
      tig gti lazygit # outil de gestion de version
      gnumake       # pour décrire les recettes de compilation
      gnupg         # GPG
      htop          # monitoring
      lsb-release   # pour les scripts qui utilisent cet outil (dont byobu)
      #libressl      # librairie pour faire du TLS et les algorithmes de crypto par OpenBSD
      ncdu          # outil pour voir l'espace utilisé
      p7zip         # compression de fichier
      parted        # partitionnement de disque
      pciutils
      pinentry      # pour taper les mots de passe gpg
      psmisc        # fournis les utilitaires comme killall, fuser, pstree
      #python        # python -- python -m SimpleHTTPServer 8000
      shared_mime_info  # MIME info
      tmux          # nécessaire pour byobu
      tree          # affiche une arborescence de fichiers et dossiers
      usbutils
      (import ./vim.nix)
      wget          # client HTTP console
      which         # pour connaitre le chemin d'un exécutable
  ];
  programs = {
    fish.enable = true;
    gnupg.agent.enable = true;
    git = {
      enable = true;
      package = pkgs.gitFull;
    };
  };
}
